.. _virtualization_guides:

******************************************
Virtualization and Containerization Guides
******************************************

The guides in this section cover integrating Ansible with popular tools for creating virtual machines and containers. They explore particular use cases in greater depth and provide a more "top-down" explanation of some basic features.

.. toctree::
   :maxdepth: 1

   guide_docker
   guide_kubernetes
   guide_vagrant
   guide_vmware
